<?php
/* start-wp-plugin-header */
/*
  Plugin Name: Edit WooCommerce Inventory in Spreadsheet
  Description: Manage WooCommerce products stock with a spreadsheet. This is a free addon for WP Sheet Editor plugin.
  Version: 1.1.0
  Author: VegaCorp
  Author URI: http://vegacorp.me
  Plugin URI: http://wpsheeteditor.com
 */
/* end-wp-plugin-header */

if (!defined('VGSE_WC_INVENTORY_DIR')) {
	define('VGSE_WC_INVENTORY_DIR', __DIR__);
}

require 'inc/tgm-init.php';
if (!class_exists('WP_Sheet_Editor_WooCommerce_Inventory')) {

	class WP_Sheet_Editor_WooCommerce_Inventory {

		static private $instance = false;
		var $post_type = 'product';

		private function __construct() {
			
		}

		function notify_wrong_core_version() {
		$plugin_data = get_plugin_data( __FILE__, false, false );
			?>
			<div class="notice notice-error">
				<p><?php _e('Please update the WP Sheet Editor plugin to the version 2.0.0 or higher. The plugin "' . $plugin_data['Name'] . '" requires that version.', VGSE()->textname); ?></p>
			</div>
			<?php
		}

		function init() {

			if (version_compare(VGSE()->version, '2.0.0') < 0) {
				$this->notify_wrong_core_version();
				return;
			}

			// Exit if premium woocommerce plugin is active
			if (class_exists('WP_Sheet_Editor_WooCommerce')) {
				return;
			}

			// exit if woocommerce plugin is not active
			if (!$this->is_woocommerce_plugin_active()) {
				return;
			}

			// Disable core plugin, wc columns limit
			if (!defined('VGSE_WC_TEASER_LIMIT_COLUMNS')) {
				define('VGSE_WC_TEASER_LIMIT_COLUMNS', false);
			}

			add_action('vg_sheet_editor/editor/before_init', array($this, 'register_columns'));
			add_action('vg_sheet_editor/columns/provider_items', array($this, 'filter_columns_settings'), 10, 3);
		}

		/**
		 * Modify spreadsheet columns settings.
		 * 
		 * It changes the names and settings of some columns.
		 * @param array $spreadsheet_columns
		 * @param string $post_type
		 * @param bool $exclude_formatted_settings
		 * @return array
		 */
		function filter_columns_settings($spreadsheet_columns, $post_type, $exclude_formatted_settings) {

			if ($post_type !== $this->post_type) {
				return $spreadsheet_columns;
			}

			$new_columns = array();

			$allowed_columns = array(
				'ID',
				'title',
				'post_title',
				'status',
				'post_status',
				'_sku',
				'_backorders',
				'_manage_stock',
				'_stock_status',
				'_stock',
			);

			foreach ($spreadsheet_columns as $key => $spreadsheet_column) {
				if (in_array($key, $allowed_columns)) {
					$new_columns[$key] = $spreadsheet_column;
				}
			}
			return $new_columns;
		}

		/**
		 * Is woocommerce plugin active
		 * @return boolean
		 */
		function is_woocommerce_plugin_active() {
			if (in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')))) {
				return true;
			} else {
				return false;
			}
		}

		/**
		 * Creates or returns an instance of this class.
		 */
		static function get_instance() {
			if (null == WP_Sheet_Editor_WooCommerce_Inventory::$instance) {
				WP_Sheet_Editor_WooCommerce_Inventory::$instance = new WP_Sheet_Editor_WooCommerce_Inventory();
				WP_Sheet_Editor_WooCommerce_Inventory::$instance->init();
			}
			return WP_Sheet_Editor_WooCommerce_Inventory::$instance;
		}

		function __set($name, $value) {
			$this->$name = $value;
		}

		function __get($name) {
			return $this->$name;
		}

		/**
		 * Register spreadsheet columns
		 */
		function register_columns($editor) {
			$post_type = $this->post_type;

			if ($editor->provider->key === 'user') {
				return;
			}
			$editor->args['columns']->register_item('_sku', $post_type, array(
				'data_type' => 'meta_data',
				'unformatted' => array('data' => '_sku'),
				'column_width' => 150,
				'title' => __('SKU', VGSE()->textname),
				'type' => '',
				'supports_formulas' => true,
				'formatted' => array('data' => '_sku', 'renderer' => 'html'),
				'allow_to_hide' => true,
				'allow_to_rename' => true,
			));
			$editor->args['columns']->register_item('_manage_stock', $post_type, array(
				'data_type' => 'meta_data',
				'unformatted' => array('data' => '_manage_stock'),
				'column_width' => 150,
				'title' => __('Manage stock', VGSE()->textname),
				'type' => '',
				'supports_formulas' => true,
				'formatted' => array(
					'data' => '_manage_stock',
					'type' => 'checkbox',
					'checkedTemplate' => 'yes',
					'uncheckedTemplate' => 'no',
				),
				'default_value' => 'no',
				'allow_to_hide' => true,
				'allow_to_rename' => true,
			));

			$editor->args['columns']->register_item('_stock_status', $post_type, array(
				'data_type' => 'meta_data',
				'unformatted' => array('data' => '_stock_status'),
				'column_width' => 150,
				'title' => __('Stock status', VGSE()->textname),
				'type' => '',
				'supports_formulas' => true,
				'formatted' => array(
					'data' => '_stock_status',
					'type' => 'checkbox',
					'checkedTemplate' => 'instock',
					'uncheckedTemplate' => 'outofstock',
				),
				'default_value' => 'instock',
				'allow_to_hide' => true,
				'allow_to_rename' => true,
			));

			$editor->args['columns']->register_item('_stock', $post_type, array(
				'data_type' => 'meta_data',
				'unformatted' => array('data' => '_stock'),
				'column_width' => 75,
				'title' => __('Stock', VGSE()->textname),
				'type' => '',
				'supports_formulas' => true,
				'formatted' => array('data' => '_stock'),
				'allow_to_hide' => true,
				'allow_to_rename' => true,
			));

			$editor->args['columns']->register_item('_backorders', $post_type, array(
				'data_type' => 'meta_data',
				'unformatted' => array('data' => '_backorders'),
				'column_width' => 150,
				'title' => __('Allow backorders', VGSE()->textname),
				'type' => '',
				'supports_formulas' => true,
				'formatted' => array('data' => '_backorders',
					'editor' => 'select',
					'selectOptions' => array(
						'no' => __('Do not allow', 'woocommerce'),
						'notify' => __('Allow, but notify customer', 'woocommerce'),
						'yes' => __('Allow', 'woocommerce'),
					)
				),
				'default_value' => 'no',
				'allow_to_hide' => true,
				'allow_to_rename' => true,
			));
		}

	}

}

if (!function_exists('WP_Sheet_Editor_WooCommerce_Inventory_Obj')) {

	function WP_Sheet_Editor_WooCommerce_Inventory_Obj() {
		return WP_Sheet_Editor_WooCommerce_Inventory::get_instance();
	}

}


add_action('vg_sheet_editor/initialized', 'WP_Sheet_Editor_WooCommerce_Inventory_Obj');
